pub struct TranscriptData<F, C> { /* private fields */ }Expand description
Raw transcript data captured by a prover and replayed by a verifier.
Implementations
Sourceimpl<F, C> TranscriptData<F, C>
impl<F, C> TranscriptData<F, C>
Sourcepub fn new(fields: Vec<F>, commitments: Vec<C>) -> Self
pub fn new(fields: Vec<F>, commitments: Vec<C>) -> Self
Create transcript data from field and commitment streams.
Sourcepub fn commitments(&self) -> &[C]
pub fn commitments(&self) -> &[C]
Returns the recorded commitments.
Sourcepub fn as_slices(&self) -> (&[F], &[C])
pub fn as_slices(&self) -> (&[F], &[C])
Returns field and commitment slices for verifier construction.
Sourcepub fn into_parts(self) -> (Vec<F>, Vec<C>)
pub fn into_parts(self) -> (Vec<F>, Vec<C>)
Consume and return the underlying vectors.
Sourcepub fn size_in_bytes(&self) -> usize
pub fn size_in_bytes(&self) -> usize
Returns the total byte size of the recorded transcript data.