Crate miden_stark_transcript

Crate miden_stark_transcript 

Transcript channels for Fiat-Shamir protocols with raw field/commitment storage.

This crate provides:

Structs

ProverTranscript
Prover channel that records transcript data and observes into the challenger.
TranscriptData
Raw transcript data captured by a prover and replayed by a verifier.
VerifierTranscript
Verifier channel that reads transcript data and observes into the challenger.

Enums

TranscriptError
Errors that can occur during transcript consumption.

Traits

Channel
Shared base trait for ProverChannel and VerifierChannel.
ProverChannel
Prover-side channel interface for transcript operations.
TranscriptChallenger
Bundle of challenger bounds required by transcript channels.
VerifierChannel
Verifier-side channel interface for transcript operations.