Transcript channels for Fiat-Shamir protocols with raw field/commitment storage.
This crate provides:
ProverTranscriptandProverChannelfor prover-side recording.VerifierTranscriptandVerifierChannelfor verifier-side reading.
Structs
- Prover
Transcript - Prover channel that records transcript data and observes into the challenger.
- Transcript
Data - Raw transcript data captured by a prover and replayed by a verifier.
- Verifier
Transcript - Verifier channel that reads transcript data and observes into the challenger.
Enums
- Transcript
Error - Errors that can occur during transcript consumption.
Traits
- Channel
- Shared base trait for
ProverChannelandVerifierChannel. - Prover
Channel - Prover-side channel interface for transcript operations.
- Transcript
Challenger - Bundle of challenger bounds required by transcript channels.
- Verifier
Channel - Verifier-side channel interface for transcript operations.